@@ -1,6 +1,5 @@
-require_relative 'qi_libs_base'
+require_relative 'sisu_version'
 module Project_details
-  require_relative 'sisu_version'
   include SiSUversion
   def self.name
     'SiSU'
@@ -228,6 +227,9 @@ module Version_info
     else nil
     end
   end
+  def self.version_number(vi)
+    vi[:version]
+  end
   def self.version_number_use(vi)
     (git_version_extract.nil?) \
     ? (vi[:version])
@@ -267,6 +269,9 @@ module Version_info
         match(hsh[:version])[1]
       hsh
     end
+    def self.version_number
+      Version_info::Current.setting_stable[:version_number]
+    end
     def self.content_stable
       Version_info.contents(setting_stable)
     end
@@ -281,7 +286,7 @@ module Version_info
       }
     end
     def self.setting_stable
-      settings(SiSU_version_next_stable)
+      settings(SiSU_version)
     end
     def self.content_stable(rel)
       Version_info.contents(setting_stable,rel)
@@ -384,10 +389,8 @@ proceed? }
     def self.changelog_header(vi)
       vn=version_number(vi)
       <<-WOK
-** #{vn}.orig.tar.xz (#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})
-http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
-http://www.jus.uio.no/sisu/pkg/src/sisu_#{vn}.orig.tar.xz
-  sisu_#{vn}.orig.tar.xz
+* sisu_#{vn}.orig.tar.xz (#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})
+  http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
       WOK
     end
     def self.changelog_header_release(filename,ch,vi)
@@ -401,8 +404,8 @@ proceed? }
         if File.writable?(fn)
           changelog_arr_current = IO.readlines(fn)
           changelog_arr_next=changelog_arr_current.each.map do |line|
-            if line =~/^\*\* [0-9]+\.[0-9]+\.[0-9]+(?:_pre_rel)?\.orig\.tar\.xz \(Open commit window: [0-9]{4}-[0-9]{2}-[0-9]{2}; Pre-Release\)\)$/
-              "** #{vi[:version]}.orig.tar.xz " \
+            if line =~/^\*\s+sisu_[0-9]+\.[0-9]+\.[0-9]+(?:_pre_rel)?\.orig\.tar\.xz \(Open commit window: [0-9]{4}-[0-9]{2}-[0-9]{2}; Pre-Release\)\)$/
+              "** sisu_#{vi[:version]}.orig.tar.xz " \
               + "(#{vi[:date]}:#{vi[:date_stamp].gsub(/20\d\dw/,'')})\n"
             else line
             end
@@ -434,10 +437,8 @@ proceed? }
     def self.changelog_header_pre_release(vi)
       vn=version_number(vi)
       <<-WOK
-** #{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release))
-http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
-http://www.jus.uio.no/sisu/pkg/src/sisu_#{vn}.orig.tar.xz
-  sisu_#{vn}.orig.tar.xz
+* #{vn}.orig.tar.xz (Open commit window: #{vi[:date]}; Pre-Release))
+  http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=log;h=refs/tags/sisu_#{vn}
       WOK
     end
     def self.changelog_header_pre_release_write(filename,ch)
@@ -481,7 +482,7 @@ proceed? }
     end
     def self.tag_upstream
       system(%{
-        git tag -a sisu_#{SiSU_version_next_stable} -m"SiSU #{SiSU_version_next_stable}"
+        git tag -a sisu_#{SiSU_version} -m"SiSU #{SiSU_version}"
       })
     end
     def self.changelog_header_commit(rel=:release)
@@ -672,3 +673,4 @@ module Package
     WOK
   end
 end
+__END__
